#include "xbee_uart.h"

#include "SerialPort/include/SerialPort.h"
using namespace org::ysuga;

static SerialPort *pSerialPort;

int uart_block = 0;

/****************************/
/* For windows PC.          */
/* Change for your Computer */
/****************************/
char *comport = "\\\\.\\COM9";


/**
 * @brief UART Initialization
 */
void uart_setup()
{
	pSerialPort = new SerialPort(comport, 9600);
}

/**
 * @brief Set Blocking Policy
 *
 * @param policy TRUE: block when receive buffer is not empty. FALSE: non-block.
 */
void uart_setBlockingPolicy(int policy) {
	uart_block = policy;
}


/**
 * @brief check receive buffer.
 *
 * @return more than zero if buffer is not empty.
 */
int uart_isReceived() {
	return pSerialPort->GetSizeInRxBuffer();
}

/**
 * @brief send 1 byte
 *
 * @param c data packet
 */
void uart_putc(char c)
{
	pSerialPort->Write(&c, 1);
	Sleep(10);
}

/**
 * @brief receive 1 byte. blocking behavior is defined by setBlockingPolicy function.
 *
 * @param c receive buffer.
 * @return zero if success. if non-block mode, negative if buffer is empty.
 */
int uart_getc(char* c) {
	if(uart_block) {
		while(!uart_isReceived()) {
		}
	} else {
		if(!uart_isReceived()) {
			return -1;
		}
	}
	pSerialPort->Read(c, 1);
	return 0;
}

